/***************************************************************************
                          confwizard.h  -  description
                             -------------------
    begin                : Son Jun 16 2002
    copyright            : (C) 2002 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CONFWIZARD_H
#define CONFWIZARD_H

#include <kwizard.h>

class TQButtonGroup;
class TQCheckBox;
class TQVBoxLayout;
class TQHBoxLayout; 
class TQGridLayout;
class TQRadioButton;
class KComboBox;
class KLineEdit;
class KPushButton;
class KURLLabel;
class TQLabel;
class TQWidget;
class SqlWidget;
/** KBarcodes configuration wizard.
  */
class ConfWizard : public KWizard
{ 
    TQ_OBJECT
  

    public:
        ConfWizard( TQWidget* parent = 0, const char* name = 0, bool modal = true );
        ~ConfWizard();

        void showPage( TQWidget* page );

        // used in dsmainwindow.cpp
        // not a clean API, but I am lazy :-(
        TQCheckBox* checkDatabase;

    private slots:
        void testSettings( bool b );
        void create();
        void example();
        void useDatabase();

    protected slots:
        void accept();
        
    private:
        void setupPage1();
        void setupPage0();
        void setupPage2();
        void setupPage3();

        SqlWidget* sqlwidget;
        
        TQWidget* page;
        TQLabel* logo;
        TQLabel* TextLabel2_2;
        KURLLabel* KURLLabel1;
        TQWidget* page_2;
        TQLabel* TextLabel1;
        TQLabel* TextLabel2;
        TQLabel* TextLabel3;
        TQLabel* TextLabel4;
        TQLabel* TextLabel5;
        TQLabel* TextLabel6;
        KPushButton* buttonTest;
        TQWidget* page_3;
        TQLabel* TextLabel1_2;
        KPushButton* buttonCreate;
        KPushButton* buttonExample;
        TQButtonGroup* groupDatabase;

    protected:
        TQVBoxLayout* pageLayout;
        TQHBoxLayout* Layout8;
        TQVBoxLayout* Layout7;
        TQVBoxLayout* pageLayout_2;
        TQVBoxLayout* pageLayout_4;
        TQHBoxLayout* Layout5;
        TQVBoxLayout* Layout3;
        TQVBoxLayout* Layout4;
        TQVBoxLayout* Layout6;
        TQVBoxLayout* pageLayout_3;
        TQVBoxLayout* Layout5_2;
};

#endif // CONFWIZARD_H
